#
# spec file for package trytond
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 - 2018 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define majorver 4.2
%define base_name tryton
Name:           trytond
Version:        %{majorver}.22
Release:        lp150.2.19.1

Summary:        An Enterprise Resource Planning (ERP) system
License:        GPL-3.0-or-later
Group:          Productivity/Office/Management
Url:            http://www.tryton.org/
Source0:        http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz
#Patch0:       	trytond340.patch
Source1:        tryton-server.README.SUSE
Source2:        trytond.conf.example
Source3:        %{name}.conf
Source4:        %{name}_log.conf
# GNU Health patch for user login
Patch0:         trytond_get_login.patch
Patch1:         trytond42_psql10.diff
Source20:       %{name}.service
# List of additional build dependencies
BuildRequires:  fdupes
BuildRequires:  postgresql
BuildRequires:  postgresql-server
BuildRequires:  python3-Werkzeug
BuildRequires:  python3-bcrypt
BuildRequires:  python3-lxml
BuildRequires:  python3-psycopg2
BuildRequires:  python3-pydot3
BuildRequires:  python3-python-sql
BuildRequires:  python3-setuptools
BuildRequires:  python3-wrapt
BuildRequires:  systemd-rpm-macros
Requires:       libreoffice-pyuno
Requires:       postgresql-server
Requires:       python3-Genshi
Requires:       python3-Levenshtein
Requires:       python3-Sphinx
Requires:       python3-Werkzeug
Requires:       python3-bcrypt
Requires:       python3-dateutil
Requires:       python3-lxml
Requires:       python3-mock
Requires:       python3-polib
Requires:       python3-psycopg2
Requires:       python3-python-sql
Requires:       python3-relatorio
Requires:       python3-simpleeval
Requires:       python3-wrapt
Requires:       unoconv
Requires(pre): 	/usr/sbin/groupadd
Requires(pre): 	/usr/sbin/useradd
# Post requires update-alternatives to install tool update-alternatives.
#Requires(post): update-alternatives

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%{?systemd_requires}

%description
This package contains the server of the Tryton application platform,
the latter of which is a three-tier high-level general purpose
application platform written in Python, using Postgresql as the
database engine. Tryton provides modularity, scalability and
security.

%prep
%setup -q 
cp %{S:1} .
cp %{S:2} .
%patch0 -p0
%patch1 -p1 -F2

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%_prefix --root=%buildroot 
# only for systemd
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/%{base_name}
install -p -m 640 %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/%{base_name}/%{name}.conf
install -p -m 640 %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/%{base_name}/%{name}_log.conf

mkdir -p $RPM_BUILD_ROOT%{_unitdir}
install -p -m 644 %{SOURCE20} $RPM_BUILD_ROOT%{_unitdir}/%{name}.service

mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/{lib,log}/%{base_name}
%fdupes -s %{buildroot}

%pre
getent group tryton > /dev/null || %{_sbindir}/groupadd -r tryton
getent passwd tryton > /dev/null || %{_sbindir}/useradd -r -g tryton \
       -d %{_localstatedir}/lib/%{name} -s /sbin/nologin \
	-c 'Tryton ERP' tryton
%service_add_pre trytond.service

%post
%service_add_post trytond.service
# Postgresql 96 is required for tryton series 4.2.x!
#update-alternatives --set postgresql /usr/lib/postgresql96

%preun
%service_del_preun trytond.service

%postun
%service_del_postun trytond.service

%files 
#%files 
%defattr(-,root,root)
%doc README tryton-server.README.SUSE trytond.conf.example LICENSE doc/*
%{python3_sitelib}/*
%dir %{_sysconfdir}/%{base_name}
%{_bindir}/%{name}
%{_bindir}/%{name}-admin
%{_bindir}/%{name}-cron
%{_unitdir}/%{name}.service
%attr(640,root,tryton) %config(noreplace)%{_sysconfdir}/%{base_name}/%{name}.conf
%attr(640,root,tryton) %config(noreplace)%{_sysconfdir}/%{base_name}/%{name}_log.conf
%attr(755,tryton,tryton) %dir %{_localstatedir}/lib/%{base_name}
%attr(755,tryton,tryton) %dir %{_localstatedir}/log/%{base_name}

%changelog
* Fri Jun 14 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.2.22 - Bugfix Release
* Mon Dec 10 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.2.17 - Bugfix Release
* Tue Nov 13 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.2.16 - Bugfix Release
* Wed Aug 22 2018 axel.braun@gmx.de
- Version 4.2.15 - Bugfix Release (boo#1107771)
* Sat Aug  4 2018 axel.braun@gmx.de
- Version 4.2.14 - Bugfix Release
* Thu Jul 19 2018 axel.braun@gmx.de
- trytond42_psql10.diff applied for postgres10 compatibility
  Kudos to mbehrle@m9s.biz!
* Wed Jul 11 2018 axel.braun@gmx.de
- Version 4.2.13 - Bugfix Release
* Tue Jun 12 2018 axel.braun@gmx.de
- boo#1096706 set postgres96 using update-alternatives (openQA failure)
* Mon Jun 11 2018 axel.braun@gmx.de
- Version 4.2.12 - Bugfix Release
  boo#1096706 requirement for postgres96 fixed
  copyright to log file and readme added
  Specfile cleaned up
* Sat May 12 2018 axel.braun@gmx.de
- Version 4.2.11 - Bugfix Release
* Fri Apr 27 2018 axel.braun@gmx.de
- requires postgres96, otherwise trytond-admin fails (Leap 15)
* Fri Mar  2 2018 axel.braun@gmx.de
- Version 4.2.10 - Bugfix Release
* Sat Feb 17 2018 axel.braun@gmx.de
- user_login.patch replaced by trytond_get_login.patch
  see boo#1078111
* Fri Jan  5 2018 axel.braun@gmx.de
- Version 4.2.9 - Bugfix Release
* Tue Dec  5 2017 axel.braun@gmx.de
- Version 4.2.8 - Bugfix Release
* Thu Nov  9 2017 axel.braun@gmx.de
- Version 4.2.7 - Bugfix Release
* Thu Sep 14 2017 axel.braun@gmx.de
- Documentation updated
* Thu Aug 10 2017 axel.braun@gmx.de
- Version 4.2.6
  bugfix release
  typo in trytond.conf removed
* Mon Jul 10 2017 axel.braun@gmx.de
- default setting for database access in trytond.conf
* Mon Jul  3 2017 axel.braun@gmx.de
- Version 4.2.5
* Tue Jun 20 2017 axel.braun@gmx.de
- Patch for user login user_login.patch from GNU Health 3.20 applied
  trytond_server.diff removed as not needed anymore
* Tue Jun  6 2017 axel.braun@gmx.de
- Version 4.2.4
* Mon Apr  3 2017 axel.braun@gmx.de
- Version 4.2.3
* Fri Mar 10 2017 axel.braun@gmx.de
- Version 4.2.2
* Fri Jan  6 2017 axel.braun@gmx.de
- Version 4.2.1
* Mon Nov 28 2016 axel.braun@gmx.de 
- Tryton Release 4.2
* Wed Aug 24 2016 axel.braun@gmx.de
- Update description
- Add missing %%service_add_pre and convert open-coded other
  three scriptlets to %%service_*.
* Tue Jul  5 2016 axel.braun@gmx.de
- version 4.0.2
* Mon May  2 2016 axel.braun@gmx.de 
- Tryton Release 4.0
* Mon Mar 28 2016 axel.braun@gmx.de
- patch for security vulnerability applied, see
  https://savannah.gnu.org/forum/forum.php?forum_id=8482
* Sun Jan 17 2016 axel.braun@gmx.de
- Installation of sao (webfrontend) documented
* Mon Oct 19 2015 axel.braun@gmx.de 
- Tryton Release 3.8
* Wed May 27 2015 axel.braun@gmx.de
- version 3.6.1
  * clean up of specfile
* Wed Apr 15 2015 axel.braun@gmx.de 
- Tryton Release 3.6
* Sat Feb 28 2015 axel.braun@gmx.de
- sample file for confirguration added (trytond.conf.example)
  tryton-server.README.SUSE updated
* Fri Nov 14 2014 axel.braun@gmx.de
- systemd startup file corrected, sample file for log config added
* Tue Nov  4 2014 axel.braun@gmx.de
- added trytond.conf
* Sun Nov  2 2014 axel.braun@gmx.de
- version 3.4
* Wed Oct 23 2013 axel.braun@gmx.de
- new branch 3.0, added python-sql
* Tue Oct 22 2013 axel.braun@gmx.de
- Tryton 3.0, spec file adapted
* Sat Jun 22 2013 axel.braun@gmx.de
- new spec with regard to systemd
- setup of user tryton if not existing
* Sun Mar 29 2009 axel.braun@gmx.de
- packaged tryton version 1.0.3 using the buildservice spec file wizard
